AttributeName

Enum AttributeName 

#[non_exhaustive]
#[repr(u16)]
pub enum AttributeName {
Show 101 variants Accesskey = 79, Align = 72, AllowBreak = 15, Alt = 46, Base = 40, Bgcolor = 41, BindingTime = 18, BlueprintValue = 23, Break = 22, Class = 8, Colname = 74, Colnum = 47, Color = 26, Cols = 88, Colsep = 86, Colwidth = 65, Coords = 25, Dest = 6, EditHeight = 90, EditWidth = 20, Editfit = 21, Editscale = 83, EnumTable = 35, Filename = 31, Fit = 68, Float = 42, Font = 61, Frame = 14, Generator = 63, Gid = 51, Height = 16, HelpEntry = 58, Href = 67, HtmlFit = 55, HtmlHeight = 97, HtmlScale = 85, HtmlWidth = 69, Index = 32, IntervalType = 60, ItemLabelPos = 70, KeepWithPrevious = 54, L = 43, Level = 50, MimeType = 96, Morerows = 3, Name = 33, NamePattern = 89, Nameend = 81, Namest = 19, Nohref = 0, Notation = 87, NoteType = 44, Onblur = 5, Onclick = 98, Ondblclick = 12, Onfocus = 100, Onkeydown = 95, Onkeypress = 73, Onkeyup = 37, Onmousedown = 64, Onmousemove = 71, Onmouseout = 1, Onmouseover = 56, Onmouseup = 39, Orient = 30, Pgwide = 29, ResolutionPolicy = 91, Rotate = 57, Rowsep = 13, S = 52, Scale = 76, Sd = 92, Shape = 38, ShortLabel = 11, ShowContent = 36, ShowResourceAliasName = 75, ShowResourceCategory = 27, ShowResourceLongName = 53, ShowResourceNumber = 10, ShowResourcePage = 7, ShowResourceShortName = 9, ShowResourceType = 2, ShowSee = 99, Si = 77, Spanname = 4, Style = 45, T = 80, Tabindex = 93, Tabstyle = 48, TexRender = 66, Title = 94, Type = 34, Uuid = 59, Validity = 84, Valign = 49, View = 24, Width = 62, xmlSpace = 82, xmlns = 28, xmlnsXsi = 17, xsiSchemalocation = 78,
}
Enum of all attribute names in Autosar

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Accesskey = 79

ACCESSKEY



Align = 72

ALIGN



AllowBreak = 15

ALLOW-BREAK



Alt = 46

ALT



Base = 40

BASE



Bgcolor = 41

BGCOLOR



BindingTime = 18

BINDING-TIME



BlueprintValue = 23

BLUEPRINT-VALUE



Break = 22

BREAK



Class = 8

CLASS



Colname = 74

COLNAME



Colnum = 47

COLNUM



Color = 26

COLOR



Cols = 88

COLS



Colsep = 86

COLSEP



Colwidth = 65

COLWIDTH



Coords = 25

COORDS



Dest = 6

DEST



EditHeight = 90

EDIT-HEIGHT



EditWidth = 20

EDIT-WIDTH



Editfit = 21

EDITFIT



Editscale = 83

EDITSCALE



EnumTable = 35

ENUM-TABLE



Filename = 31

FILENAME



Fit = 68

FIT



Float = 42

FLOAT



Font = 61

FONT



Frame = 14

FRAME



Generator = 63

GENERATOR



Gid = 51

GID



Height = 16

HEIGHT



HelpEntry = 58

HELP-ENTRY



Href = 67

HREF



HtmlFit = 55

HTML-FIT



HtmlHeight = 97

HTML-HEIGHT



HtmlScale = 85

HTML-SCALE



HtmlWidth = 69

HTML-WIDTH



Index = 32

INDEX



IntervalType = 60

INTERVAL-TYPE



ItemLabelPos = 70

ITEM-LABEL-POS



KeepWithPrevious = 54

KEEP-WITH-PREVIOUS



L = 43

L



Level = 50

LEVEL



MimeType = 96

MIME-TYPE



Morerows = 3

MOREROWS



Name = 33

NAME



NamePattern = 89

NAME-PATTERN



Nameend = 81

NAMEEND



Namest = 19

NAMEST



Nohref = 0

NOHREF



Notation = 87

NOTATION



NoteType = 44

NOTE-TYPE



Onblur = 5

ONBLUR



Onclick = 98

ONCLICK



Ondblclick = 12

ONDBLCLICK



Onfocus = 100

ONFOCUS



Onkeydown = 95

ONKEYDOWN



Onkeypress = 73

ONKEYPRESS



Onkeyup = 37

ONKEYUP



Onmousedown = 64

ONMOUSEDOWN



Onmousemove = 71

ONMOUSEMOVE



Onmouseout = 1

ONMOUSEOUT



Onmouseover = 56

ONMOUSEOVER



Onmouseup = 39

ONMOUSEUP



Orient = 30

ORIENT



Pgwide = 29

PGWIDE



ResolutionPolicy = 91

RESOLUTION-POLICY



Rotate = 57

ROTATE



Rowsep = 13

ROWSEP



S = 52

S



Scale = 76

SCALE



Sd = 92

SD



Shape = 38

SHAPE



ShortLabel = 11

SHORT-LABEL



ShowContent = 36

SHOW-CONTENT



ShowResourceAliasName = 75

SHOW-RESOURCE-ALIAS-NAME



ShowResourceCategory = 27

SHOW-RESOURCE-CATEGORY



ShowResourceLongName = 53

SHOW-RESOURCE-LONG-NAME



ShowResourceNumber = 10

SHOW-RESOURCE-NUMBER



ShowResourcePage = 7

SHOW-RESOURCE-PAGE



ShowResourceShortName = 9

SHOW-RESOURCE-SHORT-NAME



ShowResourceType = 2

SHOW-RESOURCE-TYPE



ShowSee = 99

SHOW-SEE



Si = 77

SI



Spanname = 4

SPANNAME



Style = 45

STYLE



T = 80

T



Tabindex = 93

TABINDEX



Tabstyle = 48

TABSTYLE



TexRender = 66

TEX-RENDER



Title = 94

TITLE



Type = 34

TYPE



Uuid = 59

UUID



Validity = 84

VALIDITY



Valign = 49

VALIGN



View = 24

VIEW



Width = 62

WIDTH



xmlSpace = 82

xml:space



xmlns = 28

xmlns



xmlnsXsi = 17

xmlns:xsi



xsiSchemalocation = 78

xsi:schemaLocation

Implementations

Source

impl AttributeName

pub fn from_bytes( input: &[u8], ) -> Result<AttributeName, ParseAttributeNameError>

derive an enum entry from an input string using a perfect hash function

Errors

ParseAttributeNameError: The input string did not match the name of any enum item

pub fn to_str(&self) -> &'static str

get the str corresponding to an item

The returned &str has static lifetime, becasue it is a reference to an entry in a list of constants